@@ -797,8 +797,12 @@ class LockAPI(Resource):
                               "error": 'Task already locked!'}
                     return result, 409
 
-            if not has_permission_any('task_update_lock_all', 'task_update_all'):
-                # You can only lock tasks to your own account if are not authorized to update all locks.
+            if has_permission_any('task_update_lock_all', 'task_update_all'):
+                # When a user has a task_update_lock_all and/or task_update_all permission, the lock
+                # may be (over)written at all times to the specified user.
+                task.lock = user
+            else:
+                # When a user does not have an *_all permission, the user may still lock a task of itself.
                 if user == current_user:
                     # This is allowed! A user can lock its own to task itself.
                     task.lock = user
